@@ -39,6 +39,8 @@ class ExcelDashboarder:
 
     const_str__config_label__str_wb_set_properties: str = "workbook.set_properties"
 
+    const_str__config_label__str_ws_set_column: str = "worksheet.set_column"
+
     _logger: Logger = getLogger(__name__)
 
     # This is the repository of all the registered widgets:
@@ -416,8 +418,8 @@ class ExcelDashboarder:
         ws_the_worksheet.hide_gridlines(option=2)
 
         # for each "worksheet.set_column"
-        if "worksheet.set_column" in dict_worksheet_config:
-            for i_set_column in dict_worksheet_config["worksheet.set_column"]:
+        if self.const_str__config_label__str_ws_set_column in dict_worksheet_config:
+            for i_set_column in dict_worksheet_config[self.const_str__config_label__str_ws_set_column]:
 
                 # We instantiate the cell format, if any was provided
                 dict_the_format: dict = i_set_column.get("cell_format", None)
